@@ -239,16 +239,30 @@ LOCAL_DEBUG_OUT( "item(\"%s\")->minipixmap(\"%s\")->icon(%p)", mdi->item?mdi->it
     /* optional menu items : */
     /* add label */
     if( mdi->item )
-        add_astbar_label( item->bar, 3, 0, 0, ALIGN_LEFT|ALIGN_VCENTER, 0, 0, mdi->item, AS_Text_ASCII );
+        add_astbar_label( item->bar, 3, 0, 0, ALIGN_LEFT|ALIGN_VCENTER, 0, 0, mdi->item,
+		mdi->fdata->name_encoding );
     /* add hotkey */
     if( mdi->item2 )
-        add_astbar_label( item->bar, 4, 0, 0, ALIGN_RIGHT|ALIGN_VCENTER, 0, 0, mdi->item2, AS_Text_ASCII );
+        add_astbar_label( item->bar, 4, 0, 0, ALIGN_RIGHT|ALIGN_VCENTER, 0, 0, mdi->item2, mdi->fdata->name_encoding );
 
     item->flags = 0 ;
     if( mdi->fdata->func == F_POPUP )
     {
         if( (item->submenu = FindPopup (mdi->fdata->text, True)) == NULL )
             set_flags( item->flags, AS_MenuItemDisabled );
+		else
+		{
+			MenuDataItem *smdi = item->submenu->first ;
+
+			while( smdi ) 
+			{
+				if( smdi->fdata->func != F_TITLE )
+					break;
+				smdi = smdi->next ;
+			}	 
+			if( smdi == NULL ) 
+				set_flags( item->flags, AS_MenuItemDisabled );	
+		}	 
     }else if( get_flags( mdi->flags, MD_Disabled ) || mdi->fdata->func == F_NOP )
         set_flags( item->flags, AS_MenuItemDisabled );
 
@@ -763,7 +777,7 @@ static inline void
 run_item_submenu( ASMenu *menu, int item )
 {
 LOCAL_DEBUG_CALLER_OUT( "%p, %d, submenu(%p)", menu, item, menu->items[item].submenu );
-    if( menu->items[item].submenu )
+    if( menu->items[item].submenu && !get_flags( menu->items[item].flags, AS_MenuItemDisabled ) )
     {
         int x = menu->main_canvas->root_x+(int)menu->main_canvas->bw ;
         int y ;
@@ -1372,7 +1386,7 @@ show_asmenu( ASMenu *menu, int x, int y )
 		destroy_asdb_record( db_rec, False );
     }
     /* lets make sure we got everything right : */
-    check_hints_sanity (ASDefaultScr, hints );
+    check_hints_sanity (ASDefaultScr, hints, &status, menu->main_canvas->w );
     check_status_sanity (ASDefaultScr, &status);
 
 #if 0
